@@ -192,7 +192,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 	{
 		cairo_translate (cr, 0.5, 0.5);
 
-		if (params->enable_glow && !params->active && !params->disabled && !params->is_default)
+		if (params->enable_shadow && !params->active && !params->disabled && !params->is_default)
 		{
 			CairoColor shadow;
 
@@ -220,7 +220,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 			cairo_stroke (cr);
 		}
 
-		if (!(params->enable_glow && !params->active && !params->disabled))
+		if (!(params->enable_shadow && !params->active && !params->disabled))
 			params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width-1, height-1, params->radius+1, params->corners);
 		cairo_translate (cr, -0.5, -0.5);
 	}
@@ -262,7 +262,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 	}
 
 	/* Border */
-	if (params->is_default) /* || (params->prelight && params->enable_glow)) */
+	if (params->is_default) /* || (params->prelight && params->enable_shadow)) */
 		border_normal = colors->spot[2];
 	if (params->disabled)
 		ge_cairo_set_color (cr, &border_disabled);
@@ -651,7 +651,6 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
                            const TabParameters    *tab,
                            int x, int y, int width, int height)
 {
-
 	const CairoColor *border        = &colors->shade[5];
 	const CairoColor *stripe_fill   = &colors->spot[1];
 	const CairoColor *stripe_border = &colors->spot[2];
@@ -683,11 +682,11 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	{
 		if (params->ythickness == 3)
 			stripe_size = 3.0;
-		
+
 		height += 3.0;
 		stripe_fill_size = (tab->gap_side == CL_GAP_TOP ? stripe_size/height : stripe_size/(height-2));
 		stripe_border_pos = (tab->gap_side == CL_GAP_TOP ? (stripe_size+1.0)/height : (stripe_size+1.0)/(height-2));
-		
+
 		horizontal = TRUE;
 
 		if (tab->gap_side == CL_GAP_TOP)
@@ -697,7 +696,7 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	{
 		if (params->xthickness == 3)
 			stripe_size = 3.0;
-		
+
 		width += 3.0;
 		stripe_fill_size = (tab->gap_side == CL_GAP_LEFT ? stripe_size/width : stripe_size/(width-2));
 		stripe_border_pos = (tab->gap_side == CL_GAP_LEFT ? (stripe_size+1.0)/width : (stripe_size+1.0)/(width-2));
@@ -733,7 +732,7 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	{
 		CairoColor hilight;
 		CairoColor shade1, shade2, shade3;
-		
+
 		ge_shade_color (fill, 1.15, &hilight);
 		ge_shade_color (fill, SHADE_TOP, &shade1);
 		ge_shade_color (fill, SHADE_CENTER_TOP, &shade2);
@@ -770,9 +769,9 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	else
 	{
 		CairoColor shade1;
-		
+
 		ge_shade_color (fill, SHADE_TOP, &shade1);
-		
+
 		switch	(tab->gap_side)
 		{
 			case CL_GAP_TOP:
@@ -792,10 +791,8 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 		ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
 
 		cairo_pattern_add_color_stop_rgba (pattern, 0.0, stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.6);
-/*
-		cairo_pattern_add_color_stop_rgba (pattern, 1.0/(horizontal ? height : width), stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.34);
-		cairo_pattern_add_color_stop_rgba (pattern, 1.0/(horizontal ? height : width), stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.5);
-*/
+		/* cairo_pattern_add_color_stop_rgba (pattern, 1.0/(horizontal ? height : width), stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.34);
+		   cairo_pattern_add_color_stop_rgba (pattern, 1.0/(horizontal ? height : width), stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.5); */
 		cairo_pattern_add_color_stop_rgb  (pattern, stripe_fill_size, stripe_fill->r, stripe_fill->g, stripe_fill->b);
 		cairo_pattern_add_color_stop_rgba (pattern, stripe_fill_size, stripe_border->r, stripe_border->g, stripe_border->b, 0.72);
 		cairo_pattern_add_color_stop_rgba (pattern, stripe_border_pos, stripe_border->r, stripe_border->g, stripe_border->b, 0.72);
@@ -837,6 +834,39 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 		cairo_stroke (cr);
 		cairo_pattern_destroy (pattern);
 	}
+
+    /* In current GTK+ focus and active cannot happen together, but we are robust against it. */
+	if (params->focus && !params->active)
+	{
+		CairoColor focus_fill = tab->focus.color;
+		CairoColor fill_shade1, fill_shade2, fill_shade3;
+		CairoColor focus_border;
+
+		double focus_inset_x = ((tab->gap_side == CL_GAP_TOP || tab->gap_side == CL_GAP_BOTTOM) ? 4 : stripe_size + 3);
+		double focus_inset_y = ((tab->gap_side == CL_GAP_TOP || tab->gap_side == CL_GAP_BOTTOM) ? stripe_size + 3 : 4);
+		double border_alpha = 0.5;
+		double fill_alpha = 0.17;
+
+		ge_shade_color (&focus_fill, 0.65, &focus_border);
+		ge_shade_color (&focus_fill, 1.18, &fill_shade1);
+		ge_shade_color (&focus_fill, 1.02, &fill_shade2);
+		ge_shade_color (&focus_fill, 0.84, &fill_shade3);
+
+		ge_cairo_rounded_rectangle (cr, focus_inset_x, focus_inset_y, width-focus_inset_x*2-1, height-focus_inset_y*2-1, radius-1, CR_CORNER_ALL);
+		pattern = cairo_pattern_create_linear (0, 0, 0, height);
+
+		cairo_pattern_add_color_stop_rgba (pattern, 0.0, fill_shade1.r, fill_shade1.g, fill_shade1.b, fill_alpha);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.5, fill_shade2.r, fill_shade2.g, fill_shade2.b, fill_alpha);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.5, focus_fill.r,   focus_fill.g, focus_fill.b,  fill_alpha);
+		cairo_pattern_add_color_stop_rgba (pattern, 1.0, fill_shade3.r, fill_shade3.g, fill_shade3.b, fill_alpha);
+		cairo_set_source (cr, pattern);
+		cairo_fill_preserve (cr);
+
+		cairo_pattern_destroy (pattern);
+
+		clearlooks_set_mixed_color (cr, &params->parentbg, &focus_border, border_alpha);
+		cairo_stroke (cr);
+	}
 }
 
 static void
@@ -1561,7 +1591,8 @@ clearlooks_gummy_draw_focus (cairo_t *cr,
 	CairoColor fill = focus->color;
 	CairoColor fill_shade1, fill_shade2, fill_shade3;
 	CairoColor border;
-	
+	CairoColor parentbg = widget->parentbg;
+
 	/* Default values */
 	double xoffset = 1.5;
 	double yoffset = 1.5;
@@ -1572,12 +1603,12 @@ clearlooks_gummy_draw_focus (cairo_t *cr,
 	boolean focus_fill = TRUE;
 	boolean focus_border = TRUE;
 	boolean focus_shadow = FALSE;
-	
+
 	ge_shade_color (&fill, 0.65, &border);
 	ge_shade_color (&fill, 1.18, &fill_shade1);
 	ge_shade_color (&fill, 1.02, &fill_shade2);
 	ge_shade_color (&fill, 0.84, &fill_shade3);
-	
+
 	/* Do some useful things to adjust focus */
 	switch (focus->type)
 	{
@@ -1607,43 +1638,53 @@ clearlooks_gummy_draw_focus (cairo_t *cr,
 			yoffset = 1.5;
 			break;
 		case CL_FOCUS_TREEVIEW:
-			border_alpha = 0.5;
-			fill_alpha = 0.14;
+			parentbg = colors->base[widget->state_type];
+			xoffset = -1.5;
+			yoffset = -1.5;
+			fill_alpha = 0.08;
+			focus_border = FALSE;
 			break;
 		case CL_FOCUS_TREEVIEW_DND:
+			parentbg = colors->base[widget->state_type];
 			break;
 		case CL_FOCUS_TREEVIEW_HEADER:
 			cairo_translate (cr, -1, 0);
 			break;
 		case CL_FOCUS_TREEVIEW_ROW:
-			xoffset = -0.5; /* hack to hide vertical lines */
+			parentbg = colors->base[widget->state_type];
+			xoffset = -2.5; /* hack to hide vertical lines */
 			yoffset = 0.5;
-			radius = 0;
-			ge_shade_color (&colors->base[widget->state_type], 0.75, &border);
-			border_alpha = 1.0;
+			CLAMP (radius, 0.0, 2.0);
 			focus_fill = FALSE;
 			break;
 		case CL_FOCUS_TAB:
-			radius--;
+	        /* In current GTK+ focus and active cannot happen together, but we are robust against it.
+	         * IF the application sets the state to ACTIVE while drawing the tabs focus. */
+			if (widget->focus && !widget->active)
+				return;
+			border_alpha = 0.6;
+			fill_alpha = 0.17;
 			break;
 		case CL_FOCUS_SCALE:
 			break;
 		case CL_FOCUS_UNKNOWN:
+			/* Fallback to classic function, dots */
+			clearlooks_draw_focus (cr, colors, widget, focus, x, y, width, height);
 			return;
 			break;
 		default:
 			break;
 	};
-	
+
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, focus->line_width);
-	
+
 	ge_cairo_rounded_rectangle (cr, xoffset, yoffset, width-(xoffset*2), height-(yoffset*2), radius, widget->corners);
-	
+
 	if (focus_fill)
 	{
 		cairo_pattern_t *pattern;
-		
+
 		pattern = cairo_pattern_create_linear (0, 0, 0, height);
 		cairo_pattern_add_color_stop_rgba (pattern, 0.0, fill_shade1.r, fill_shade1.g, fill_shade1.b, fill_alpha);
 		cairo_pattern_add_color_stop_rgba (pattern, 0.5, fill_shade2.r, fill_shade2.g, fill_shade2.b, fill_alpha);
@@ -1651,22 +1692,22 @@ clearlooks_gummy_draw_focus (cairo_t *cr,
 		cairo_pattern_add_color_stop_rgba (pattern, 1.0, fill_shade3.r, fill_shade3.g, fill_shade3.b, fill_alpha);
 		cairo_set_source (cr, pattern);
 		cairo_fill_preserve (cr);
-		
+
 		cairo_pattern_destroy (pattern);
 	}
-	
+
 	if (focus_border)
 	{
-		clearlooks_set_mixed_color (cr, &widget->parentbg, &border, border_alpha);
+		clearlooks_set_mixed_color (cr, &parentbg, &border, border_alpha);
 		cairo_stroke (cr);
 	}
-	
+
 	if (focus_shadow)
 	{
 		if (radius > 0)
 			radius++;
 		ge_cairo_rounded_rectangle (cr, xoffset-1, yoffset-1, width-(xoffset*2)+2, height-(yoffset*2)+2, radius, widget->corners);
-		clearlooks_set_mixed_color (cr, &widget->parentbg, &fill, shadow_alpha);
+		clearlooks_set_mixed_color (cr, &parentbg, &fill, shadow_alpha);
 		cairo_stroke (cr);
 	}
 }
